BuildingContext class

Constructors

BuildingContext({required int levelSpaceCount, required String quote, List<String>? lineArray})

Properties

hashCode → int
The hash code for this object.
no setterinherited
levelSpaceCount → int
final
lineArray → List<String>
final
quote → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited