ParsingContext class
Constructors
-
ParsingContext({required String baseFolderPath, required String filePath, required String readTextFileFunction(String, [String])?, required String stringProcessingQuote, required dynamic processQuotedStringFunction(String, ParsingContext, int)?, required int levelSpaceCount, required String text, required List<
String> lineArray, int lineIndex = 0})
Properties
- baseFolderPath → String
-
final
- filePath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- levelSpaceCount → int
-
final
-
lineArray
→ List<
String> -
final
- lineIndex ↔ int
-
getter/setter pair
- processQuotedStringFunction → dynamic Function(String, ParsingContext, int)?
-
final
- readTextFileFunction → String Function(String, [String])?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringProcessingQuote → String
-
final
- text → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited